@@ -4,11 +4,11 @@ import python_jsonschema_objects as pjo
 
 def test_circular_references(markdown_examples):
 
-    builder = pjo.ObjectBuilder(markdown_examples['Circular References'])
+    builder = pjo.ObjectBuilder(markdown_examples["Circular References"])
     klasses = builder.build_classes()
     a = klasses.A()
     b = klasses.B()
-    a.message = 'foo'
+    a.message = "foo"
     b.author = "James Dean"
     a.reference = b
     a.reference = b
@@ -18,4 +18,6 @@ def test_circular_references(markdown_examples):
     assert a.message == "foo"
 
     serialized = a.serialize(sort_keys=True)
-    assert serialized == '{"message": "foo", "reference": {"author": "James Dean"}}'  # noqa
+    assert (
+        serialized == '{"message": "foo", "reference": {"author": "James Dean"}}'
+    )  # noqa
